summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDaniel Calviño Sánchez <danxuliu@gmail.com>2022-02-14 18:57:59 +0100
committerDaniel Calviño Sánchez <danxuliu@gmail.com>2022-02-14 19:25:39 +0100
commit4dc468003a9aa38b2d0670979f9c855eb2d85e3e (patch)
tree548aaa2df42e5e0f14d439537dced54dec19ee15
parent3b66c68bf77d8eef4e285718835d1799cdd94164 (diff)
Update image in script to run local integration tests in Docker
PHP 7.3 support was dropped for Nextcloud 24. The Docker image is updated to the same image used for integration tests in CI. Signed-off-by: Daniel Calviño Sánchez <danxuliu@gmail.com>
-rwxr-xr-xtests/integration/run-docker.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/integration/run-docker.sh b/tests/integration/run-docker.sh
index e58c61d0f..667c8575b 100755
--- a/tests/integration/run-docker.sh
+++ b/tests/integration/run-docker.sh
@@ -214,8 +214,9 @@ trap cleanUp EXIT
cd "$(dirname $0)"
# "--image XXX" option can be provided to set the Docker image to use to run
-# the integration tests (one of the "nextcloudci/phpX.Y:phpX.Y-Z" images).
-NEXTCLOUD_LOCAL_IMAGE="nextcloudci/php7.3:php7.3-5"
+# the integration tests (one of the "nextcloudci/phpX.Y:phpX.Y-Z" or
+# "ghcr.io/nextcloud/continuous-integration-phpX.Y:latest" images).
+NEXTCLOUD_LOCAL_IMAGE="ghcr.io/nextcloud/continuous-integration-php8.0:latest"
if [ "$1" = "--image" ]; then
NEXTCLOUD_LOCAL_IMAGE=$2